<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Call Logs</title>
    <style>
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            border: 1px solid #ccc;
            padding: 8px;
            text-align: left;
        }
        th {
            background-color: #f4f4f4;
        }
    </style>
</head>
<body>
    <h1>Call Logs</h1>
    <table id="callLogsTable">
        <thead>
            <tr>
                <th>Caller Number</th>
                <th>Target</th>
                <!-- Add more columns as needed -->
            </tr>
        </thead>
        <tbody>
        </tbody>
    </table>

   <script>
    const accountId = 'RA5a9529da488d47a8910e6187d54e7acb';
    const apiToken = '09f0c9f0e72a39528090b34cb7305c4a91dda58c9c53819287f31d93de33445f2aadb57ff907c518b977dc18300deb9441b4504189933d8e266fb678157a41d852ab544045596df5f220a53867081359ff5be9c210fcaf9d20edf56178df3dfbaa38eb10a41946daf01211e9f699e22fab84aa90';



    // Function to get the current UTC time and calculate the last 24 hours
    
    
    function getUTCDateRange() {
        const now = new Date(); // Current date and time
        const end = now.toISOString(); // Current time in UTC
        const start = new Date(now.getTime() - 24 * 60 * 60 * 1000).toISOString(); // 24 hours before in UTC
        return { start, end };
    }

    const { start: reportStart, end: reportEnd } = getUTCDateRange();

    let offset = 0;
    const limit = 20;
    const allCallLogs = [];

    const requestData = {
        reportStart,
        reportEnd,
        filters: [
            { anyConditionToMatch: [{ column: 'hasConverted', value: 'yes', comparisonType: 'EQUALS' }] }
        ]
    };

    async function fetchCallLogs(offset) {
        const url = `https://api.ringba.com/v2/${accountId}/calllogs?offset=${offset}&limit=${limit}`;

        const response = await fetch(url, {
            method: 'POST',
            headers: {
                'Authorization': `Token ${apiToken}`,
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(requestData)
        });

        if (response.ok) {
            const data = await response.json();
            return data.report.records;
        } else {
            throw new Error('Failed to fetch data');
        }
    }

    async function getAllCallLogs() {
        let moreData = true;

        while (moreData) {
            try {
                const records = await fetchCallLogs(offset);

                if (records.length > 0) {
                    allCallLogs.push(...records);
                    offset += limit;
                } else {
                    moreData = false; // No more data to fetch
                }
            } catch (error) {
                console.error('Error:', error);
                moreData = false;
            }
        }

        populateTable(allCallLogs);
    }

function populateTable(data) {
    const tableBody = document.querySelector('#callLogsTable tbody');
    tableBody.innerHTML = ''; // Clear any existing rows

    data.forEach(record => {
        const inboundPhoneNumber = record.inboundPhoneNumber
            ? record.inboundPhoneNumber.replace(/^\+1/, '') // Remove "+1" if it exists
            : 'N/A';

        const targetName = record.targetName || 'N/A';

        // Save the number to the database
        if (inboundPhoneNumber !== 'N/A') {
            saveToDatabase(inboundPhoneNumber);
        }

        const row = document.createElement('tr');
        row.innerHTML = `
            <td>${inboundPhoneNumber}</td>
            <td>${targetName}</td>
        `;

        tableBody.appendChild(row);
    });
}

function saveToDatabase(number) {
    
    fetch('saveNumber.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        body: `number=${encodeURIComponent(number)}`
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            console.log(`Number ${number} saved successfully!`);
        } else {
            console.error('Error saving number:', data.error);
        }
    })
    .catch(error => console.error('Error:', error));
}


    // Run the loop to get all call logs
    getAllCallLogs();
</script>

</body>
</html>
